@@ -3,11 +3,15 @@ from .destination_sftp_json.client import SftpClient
 from .destination_azblob.destination import DestinationAzBlob
 from .destination_IPFS.client import IPFSDestination
 from .source_IPFS.client import IPFSSource
+from .source_postgres.client import PostgresSource
+from .destination_postgres.client import PostgresDestination
 
 __all__ = [
     'files',
     'SftpClient',
     'DestinationAzBlob',
     'IPFSDestination',
-    'IPFSSource'
+    'IPFSSource',
+    'PostgresSource',
+    'PostgresDestination'
 ]
